@@ -72,16 +72,7 @@ if ((! isset($SP_CONFIG)) && (! isset($configfile))) {
     exit();
 }
 
-// set cookie path
-$currentCookieParams = session_get_cookie_params();
-session_set_cookie_params(
-    $currentCookieParams["lifetime"],
-    $_SERVER['SCRIPT_NAME'],
-    $currentCookieParams["domain"],
-    $currentCookieParams["secure"],
-    $currentCookieParams["httponly"]
-);
-session_start();
+require_once 'init_session.php';
 
 // suppress notice messages 
 error_reporting(error_reporting()&~E_NOTICE);
@@ -111,10 +102,15 @@ elseif ($App->getSession('LANG')) {
     $App->setLang($App->getSession('LANG'));
 }
 else {
-    require_once 'model/AppUtils.php';
-    $App->setLang(AppUtils::GetLocaleFromBrowser(
-                    $App->getConfig('DEFAULT_LANGUAGE','de'),
-                    false));
+    if ($App->getConfig('FORCE_DEFAULT_LANGUAGE') == 'true') {
+        $App->setLang($App->getConfig('DEFAULT_LANGUAGE','de'));
+    }
+    else {
+        require_once 'model/AppUtils.php';
+        $App->setLang(AppUtils::GetLocaleFromBrowser(
+                        $App->getConfig('DEFAULT_LANGUAGE','de'),
+                        false));
+    }
 }
 $App->setSkin($App->getConfig('SKINDIR','default'));
 
