@@ -527,6 +527,26 @@ class Application extends ApplicationConfig
     }
 
 
+    /**
+     * Returns the loglevel for the given module
+     *
+     * @access public
+     * @param string $message
+     * @return int $loglevel
+     */
+    function loglevelForModule($module)
+    {
+        $debug_vals   = preg_split('/,(\s+)?/',$this->DEBUG);
+        $debug_global = array_shift($debug_vals);
+        foreach ($debug_vals as $debug_entry) {
+            list($debug_module,$level) = explode(':',$debug_entry);
+            if ($debug_module == $module) {
+                return $level;
+            }
+        }
+    }
+
+
     /**
      * debug_var
      *
@@ -652,9 +672,6 @@ class Application extends ApplicationConfig
      */
     function redirect ($action,$plist=array())
     {
-        global $CURRENT_ACTION;
-        $this->setSession('LAST_ACTION',$CURRENT_ACTION);
-
         $params = session_name().'='.session_id().'&CA='.$action;
         if (is_array($plist)) {
             foreach ($plist as $var => $value) {
@@ -731,7 +748,7 @@ class Application extends ApplicationConfig
      *                                                                               * @access public
      * @param string $identifier
      */
-    function delSession ($identifier)
+    function unsetSession ($identifier)
     {
         unset ($this->_session[$identifier]);
     }
