@@ -70,8 +70,8 @@ catch (Exception $e) {
     $App->redirect('default',array('MSG'=>$exc));
 }
 
-$App->log('Authentication of '.$User->id. ' successful',1);
 // LOGIN SUCCESSFUL
+$App->log('Authentication of '.$User->id. ' successful',1);
 
 // initialize backend
 $archive_list = $User->getArchives();
@@ -81,17 +81,18 @@ $filterString = '';
 foreach ($FilterList as $Filter) {
     $filterString .= $Filter->getString();
 }
-$Backend = new Backend($base_url,$archive,$filterString);
+$Backend = new Backend($base_url,$filterString);
 
 // initialize session
 $App->setSession('ACCESS_LEVEL',$User->getAuthzLevel());
 $App->setSession('USER',$User);
 $App->setSession('Backend',$Backend);   // store backend for this session
+$App->setSession('archive',$archive);   // store current archive
 $App->setSession('FilterList',$FilterList);
 
 // defaults for extended search form
 $timerange = $App->getConfig('DEFAULT_TIMERANGE');
-$ExtQuery = new Query('');
+$ExtQuery = new Query('empty');
 $App->setSession('ExtQuery',$ExtQuery);
 
 $App->setSession('QueryList',StoredQuery::FetchList($User->id));
@@ -119,7 +120,10 @@ catch (Exception $e) {
     $App->log('Error loading application state: '.$e->getMessage());
 }
 
-// redirect user to search mask
-$App->redirect('greeting');
+// redirect after login
+if (!$redirect = $App->getSession('LOGIN_REDIRECT')) {
+    $redirect = 'greeting';
+}
+$App->redirect($redirect);
 
 ?>
