@@ -40,7 +40,7 @@ list($date_from,$date_to) = DateConvert::DateDiff($timeslice);
 $searchstring = $App->getParam('searchmin');
 
 $queryId = sha1($searchstring);
-$SimpleQuery = new Query($queryId,$searchstring,$date_from,$date_to);
+$SimpleQuery = new Query($queryId,$archive,$searchstring,$date_from,$date_to);
 $SimpleQuery->setSortOrder($sortOrder);
 $SimpleQuery->setSpam($App->getConfig('SHOW_SPAM'));
 $SimpleQuery->type = $searchMaskState;
@@ -50,7 +50,7 @@ $ExtQuery = new Query('empty');
 
 try {
     // fresh search, thus we start with position 1
-    $QueryResult = $Backend->query($SimpleQuery,0,$search_limit);
+    $QueryResult = $Backend->query($archive,$SimpleQuery,0,$search_limit);
     if ($QueryResult->found == 0) {
         $App->setMsg('MSG_NOTFOUND');
         $sessionMailId = '';
