@@ -35,8 +35,34 @@
 class EMail
 {
 
+    /** id
+     *
+     * session mail id: uniqe id of this email in this session
+     *
+     * @access public
+     * @var string
+     */
     var $id;
+
+
+    /** archive
+     *
+     * archive of this email
+     *
+     * @access public
+     * @var string
+     */
+    var $archive;
+
+    /** bennoId
+     *
+     * uniqe id in archive: <box>:<checksum>
+     *
+     * @access public
+     * @var string
+     */
     var $bennoId;
+
     var $from;
     var $to;
     var $cc;
@@ -57,9 +83,10 @@ class EMail
     var $verified;
 
 
-    function EMail ($id,$bennoId='',$from='',$to=array(),$cc=array(),$bcc=array(),$subject='',$date='',$size='',$body='',$hasAttachment=false,$verified=false)
+    function EMail ($id,$archive,$bennoId='',$from='',$to=array(),$cc=array(),$bcc=array(),$subject='',$date='',$size='',$body='',$hasAttachment=false,$verified=false)
     {
         $this->id       = $id; 
+        $this->archive  = $archive; 
         $this->bennoId  = $bennoId; 
         $this->from     = $from;
         $this->_lto     = $to;
