@@ -91,7 +91,7 @@ class QueryResult
                 $sessionMailId = $i.'_'.uniqid();   // prevent two windows accessing the same email
                 $bennoIdTable[$akt['id']] = $sessionMailId;
             }
-            $EMail = new EMail($sessionMailId,$akt['id'],$akt['From'],$akt['To'],$akt['Cc'],$akt['Bcc'],$akt['Subject'],$akt['Date'],'','',$akt['hasAttachment']);
+            $EMail = new EMail($sessionMailId,$Query->archive,$akt['id'],$akt['From'],$akt['To'],$akt['Cc'],$akt['Bcc'],$akt['Subject'],$akt['Date'],'','',$akt['hasAttachment']);
 
             array_push($mailList,$EMail);
         }
