@@ -37,11 +37,14 @@ $App->setSession('lastRequestTime',$lastRequestTime);
 
 // If this function returns a value != "", the browser will call loads
 // the page with the CA given in the return string.
-//$logoffTime = time() - $App->getConfig('SESSION_TIMEOUT') * 60;
-$logoffTime = time() - $App->getConfig('SESSION_TIMEOUT') * 10;
+$sessionTimeout = $App->getConfig('SESSION_TIMEOUT');
+if (! $sessionTimeout) {
+    $sessionTimeout = 15;
+}
+$logoffTime = time() - $sessionTimeout * 60;
 
 if ($lastRequestTime <= $logoffTime) {
-    $App->log('Session time out for user '.$USER->id);
+    $App->log('Session time out for user '.$USER->id,1);
     print 'logoff';
 }
 
