@@ -40,9 +40,11 @@ try {
     $EMail = $Backend->fetch($archive,$sessionMailId);
     $App->setSession('sessionMailId',$sessionMailId);
     $App->setSession('EMail',$EMail);
+
 }
 catch (Exception $e) {
-    $App->log($e->getMessage());
+    $errorMsg = $e->getMessage();
+    $App->log($errorMsg);
 }
 
 $permaId = base64_encode($EMail->bennoId.'@'.$EMail->archive);
@@ -72,12 +74,18 @@ catch (Exception $e) {
         $MailObject->body   = $EMail->getBody('text/html');
         $MailObject->bodytype = 'text/html';
     }
+    else {
+        $App->log('Cannot fetch email body: '.$e->getMessage(),1,'a_showEmail');
+    }
 }
 
 $mailDate = $EMail->getDate();
 $MailObject->date       = strftime($LOCALE['dateformat'],$mailDate);
 $MailObject->time       = strftime($LOCALE['timeformat'],$mailDate);
 
+if ($errorMsg) {
+    $MailObject->setError('ID_NOT_FOUND');
+}
 print json_encode($MailObject);
 eor();
 ?>
